Module: Jekyll

Defined in:
lib/jekyll_time_since.rb

Overview

These tags all work in a similar manner; they accept one parameter, which is either a date string (YYYY-MM-dd) or an ISO 8601-1:2019 datetime string (YYYY-MM-ddThh:mm).

Just a year can be specified, which implies Jan 1 at midnight. You can specify a time zone

Defined Under Namespace

Modules: TimeSince